@@ -1455,8 +1455,77 @@ test_that("docx40: Bolding, column defaults, and stub works.", {
   
 })
 
+test_that("docx41: Spanning header bold work as expected.", {
+  
+  
+  fp <- file.path(base_path, "docx/test41")
+  
+  dat <- mtcars[1:15, ]
+  
+  tbl <- create_table(dat, borders = c( "none")) %>%
+    spanning_header(cyl, disp, "Span 1", label_align = "left") %>%
+    spanning_header(hp, wt, "Span 2", underline = FALSE, bold = TRUE) %>%
+    spanning_header(qsec, vs, "Span 3", n = 10) %>%
+    spanning_header(drat, gear, "Super Duper\nWrapped Span",
+                    n = 11, level = 2, bold = TRUE) %>%
+    titles("Table 1.0", "My Nice Table", blank_row = "none", 
+           borders = c("top", "bottom")) %>%
+    footnotes("My footnote 1", "My footnote 2", 
+              blank_row = "none", borders = c("top", "bottom"))
+  
+  rpt <- create_report(fp, output_type = "DOCX", font = fnt,
+                       font_size = fsz, orientation = "landscape") %>%
+    set_margins(top = 1, bottom = 1) %>%
+    page_header("Left", c("Right1", "Right2", "Right3"), blank_row = "below") %>%
+    add_content(tbl) %>%
+    page_footer("Left1", "Center1", "Right1")
+  
+  res <- write_report(rpt)
+  res
+  res$column_widths
+  
+  expect_equal(file.exists(res$modified_path), TRUE)
+  expect_equal(res$pages, 1)
+  
+})
 
 
+test_that("docx42: Italic footnotes work as expected.", {
+  
+  
+  fp <- file.path(base_path, "docx/test42.docx")
+  
+  dat <- mtcars[1:15, ]
+  
+  tbl <- create_table(dat, borders = c( "none")) %>%
+    spanning_header(cyl, disp, "Span 1", label_align = "left") %>%
+    spanning_header(hp, wt, "Span 2", underline = FALSE, bold = FALSE) %>%
+    spanning_header(qsec, vs, "Span 3", n = 10) %>%
+    spanning_header(drat, gear, "Super Duper\nWrapped Span",
+                    n = 11, level = 2, bold = FALSE) %>%
+    titles("Table 1.0", "My Nice Table", blank_row = "none", 
+           borders = c("top", "bottom")) %>%
+    footnotes("My italic footnote1", "My italic footnote2", italics = TRUE, 
+              blank_row = "none", borders = "top") %>%
+    footnotes("My italic footnote", "My footnote 2", 
+              blank_row = "none", borders = c("bottom"))
+  
+  rpt <- create_report(fp, output_type = "DOCX", font = fnt,
+                       font_size = fsz, orientation = "landscape") %>%
+    set_margins(top = 1, bottom = 1) %>%
+    page_header("Left", c("Right1", "Right2", "Right3"), blank_row = "below") %>%
+    add_content(tbl) %>%
+    page_footer("Left1", "Center1", "Right1")
+  
+  res <- write_report(rpt)
+  res
+  res$column_widths
+  
+  expect_equal(file.exists(res$modified_path), TRUE)
+  expect_equal(res$pages, 1)
+  
+})
+
 # User Tests --------------------------------------------------------------
 
 
