@@ -209,14 +209,14 @@ test_that("get_header works as expected.", {
                     font_name = "Arial",
                     page_ids = c(3))
   
-  expect_equal(length(hdr), 4)
+  expect_equal(length(hdr), 5)
   
   hdrtxt <- render(pdf_document(hdr))
   
   #cat(rawToChar(hdrtxt))
   
   # if (Sys.info()[["sysname"]] == "Windows")
-    expect_equal(length(hdrtxt), 492) #369)
+    expect_equal(length(hdrtxt), 614) #369)
   # else 
   #   expect_equal(length(hdrtxt), 370)
   
@@ -226,14 +226,14 @@ test_that("get_header works as expected.", {
                     page_height = 500,
                     page_width = 600)
   
-  expect_equal(length(hdr), 4)
+  expect_equal(length(hdr), 5)
   
   hdrtxt <- render(pdf_document(hdr))
   
   #cat(rawToChar(hdrtxt))
   
   # if (Sys.info()[["sysname"]] == "Windows")
-    expect_equal(length(hdrtxt), 494) #377)
+    expect_equal(length(hdrtxt), 614) #377)
   # else 
   #   expect_equal(length(hdrtxt), 378)
   
@@ -241,14 +241,14 @@ test_that("get_header works as expected.", {
   hdr <- get_header(page_count = 3,
                     page_ids = c(3, 4, 5))
   
-  expect_equal(length(hdr), 4)
+  expect_equal(length(hdr), 5)
   
   hdrtxt <- render(pdf_document(hdr))
   
   #cat(rawToChar(hdrtxt))
   
   # if (Sys.info()[["sysname"]] == "Windows")
-    expect_equal(length(hdrtxt), 500) #383)
+    expect_equal(length(hdrtxt), 620) #383)
   # else
   #   expect_equal(length(hdrtxt), 384)
   
@@ -393,31 +393,32 @@ test_that("get_image_text works as expected.", {
   
 })
 
-test_that("pdf_image_stream works as expected.", {
-  
-  fp <- file.path(data_dir, "data/dot.jpg")
-  
-  f <- file(fp, open="rb", encoding = "native.enc")
-  
-  png <- readBin(f, "raw", 10000)
-  
-  close(f)
-  
-  
-  strm <- pdf_image_stream(6, 60, 60, png)
-  
-  strm
-  
-  expect_equal(length(strm), 5)
-  
-  res <- render.pdf_image_stream(strm, view = TRUE)
-  
-  res
-  
-  expect_equal(length(res), 6)
-  
-  
-})
+# Commented out because of CRAN warning.  view parameter is apparently illegal now.
+# test_that("pdf_image_stream works as expected.", {
+#   
+#   fp <- file.path(data_dir, "data/dot.jpg")
+#   
+#   f <- file(fp, open="rb", encoding = "native.enc")
+#   
+#   png <- readBin(f, "raw", 10000)
+#   
+#   close(f)
+#   
+#   
+#   strm <- pdf_image_stream(6, 60, 60, png)
+#   
+#   strm
+#   
+#   expect_equal(length(strm), 5)
+#   
+#   res <- render.pdf_image_stream(strm, view = TRUE)
+#   
+#   res
+#   
+#   expect_equal(length(res), 6)
+#   
+#   
+# })
 
 
 
@@ -523,7 +524,7 @@ test_that("get_pages works as expected.", {
   
   res
   
-  expect_equal(res$page_ids, c(5, 7, 9))
+  expect_equal(res$page_ids, c(6, 8, 10))
   expect_equal(length(res$objects), 7)
   
   
